import sys
import math


def read_gtr(fname):
    lst=[]
    f=open(fname)
    for line in f:
        fld=line.split()
        if len(fld)!=3:
            continue
        lst.append((int(fld[0]), fld[1], fld[2]))
    f.close()
    return lst

def euclidean_distance(v1, v2):
    return math.sqrt(sum(map(lambda x,y: (x-y)*(x-y), v1,v2)))

def read_vectors(fname):
    dist={}
    lst=[]
    f=open(fname)
    for line in f:
        fld=line.split()
        if len(fld)<2:
            continue
        id=int(fld[0])
        vec=[float(x) for x in fld[1:]]
        lst.append((id, vec))
    f.close()
    for id1, v1 in lst:
        for id2, v2 in lst:
            if id1<=id2:
                continue
            d=euclidean_distance(v1, v2)
            dist[id1, id2]=d
            dist[id2, id1]=d
    return dist

def read_prod(fname):
    prod={}
    f=open(fname)
    for line in f:
        fld=line.split()
        if len(fld)<3:
            continue
        id1=int(fld[0])
        id2=int(fld[1])
        d=float(fld[2])
        prod[id1,id2]=d
    f.close()
    dist={}
    for id1, id2 in prod:
        p11=prod[id1, id1]
        p22=prod[id2, id2]
        p12=prod[id1, id2]
        d=math.sqrt(p11-2*p12+p22)
        dist[id1, id2]=d
        dist[id2, id1]=d
    return dist

def compute_labeled_distances(dist, gtr):
    clsmap={}
    for id, cls, name in gtr:
        clsmap[id]=cls
    lst=[]
    for i,j in dist:
        intra=(clsmap[i]==clsmap[j])
        lst.append((dist[i,j], intra))
    return lst


def c_index(lst):
	lst.sort()
	intra=[x for x,y in lst if y]
	w=len(intra)
	sw=sum(intra)
	smin=sum((x for x,y in lst[:w]))
	smax=sum((x for x,y in lst[-w:]))
	return float(sw-smin)/(smax-smin)

if __name__=='__main__':
    if sys.argv[1]=='-implicit':
        prodfname=sys.argv[2]
        dist=read_prod(prodfname)
        print 'Read prod file: ', prodfname
        gtrfname=sys.argv[3]
    elif sys.argv[1]=='-explicit':
        vecfname=sys.argv[2]
        dist=read_vectors(vecfname)
        print 'Read vector file: ', vecfname
        gtrfname=sys.argv[3]
    else:
        vecfname=sys.argv[1]
        dist=read_vectors(vecfname)
        print 'Read vector file: ', vecfname
        gtrfname=sys.argv[2]
    gtr=read_gtr(gtrfname)
    print 'Read ground truth file: ', gtrfname
    labdist=compute_labeled_distances(dist, gtr)
    print 'Labeled distances computed.'
    print 'Performance Index:', c_index(labdist)
