import sys
import random

class Graph:
    def __init__(self, text):
        lines=text.split('\n')
        head=lines[0]
        fld=head.split()
        self.id=int(fld[1])
        self.text=text 
        assert fld[0]=='G'
        self.n=int(lines[1])
        self.nodes={}
        self.edges={}
        self.parse_nodes(lines[2:2+self.n])
        self.parse_edges(lines[2+self.n:])

    def parse_nodes(self, lines):
        for l in lines:
            fld=l.split()
            i=int(fld[0])
            attr=[float(x) for x in fld[1:]]
            self.nodes[i]=attr
            self.edges[i]=set()
            assert len(attr)==4

    def parse_edges(self, lines):
        for l in lines:
            fld=l.split()
            if len(fld)!=2:
                continue
            i=int(fld[0])
            j=int(fld[1])
            self.edges[i].add(j)
            self.edges[j].add(i)



def read_graphs(fname):
    lst=[]
    f=open(fname)
    text=''
    for line in f:
        if line[:1]=='G':
            if text:
                lst.append(Graph(text))
                text=''
        text+=line
    if text:
        lst.append(Graph(text))
    f.close()
    return lst


def compute_embedding(graphs):
    lst=[]
    for g in graphs:
        n=g.n
        e=sum((len(g.edges[e]) for e in g.edges))
        lst.append((g.id, [n, e]))
    return lst

def write_vectors(fname, vectors):
    f=open(fname, 'w')
    for v in vectors:
        f.write('%d ' % v[0])
        for x in v[1]:
            f.write('%g ' % x)
        f.write('\n')
    f.close()

if __name__=='__main__':
    infname=sys.argv[1]
    graphs=read_graphs(infname)
    print 'Graphs read:', len(graphs)
    vectors=compute_embedding(graphs)
    outfname=sys.argv[2]
    write_vectors(outfname, vectors)
